==> pip_services3_commons-3.1.4.tar.gz: pip_services3_commons-3.1.4/pip_services3_commons/validate/__init__.py <==
# -*- coding: utf-8 -*-
"""
    pip_services3_commons.validate.__init__
    ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    
    Validation frameworks exist in various languages, but since this is one of the underlying
    functions that is incorporated into (various) other packages, we decided to implement it
    in a portable format, for identical implementation across languages.
    
    :copyright: Conceptual Vision Consulting LLC 2018-2019, see AUTHORS for more details.
    :license: MIT, see LICENSE for more details.
"""

__all__ = [
    'ValidationResultType', 'ValidationResult', 'ValidationException',
    'IValidationRule', 'AndRule', 'OrRule', 'NotRule', 'ObjectComparator',
    'ValueComparisonRule', 'PropertiesComparisonRule',
    'OnlyOneExistRule', 'AttributeError', 'ExcludedRule', 'IncludedRule',
    'Schema', 'PropertySchema', 'ObjectSchema', 'ArraySchema', 'MapSchema',
    'FilterParamsSchema', 'PagingParamsSchema'
]

from .ValidationResultType import ValidationResultType
from .ValidationResult import ValidationResult
from .ValidationException import ValidationException
from .IValidationRule import IValidationRule
from .AndRule import AndRule
from .OrRule import OrRule
from .NotRule import NotRule
from .ObjectComparator import ObjectComparator
from .ValueComparisonRule import ValueComparisonRule
from .PropertiesComparisonRule import PropertiesComparisonRule
from .OnlyOneExistRule import OnlyOneExistRule
from .AtLeastOneExistRule import AtLeastOneExistRule
from .ExcludedRule import ExcludedRule
from .IncludedRule import IncludedRule
from .Schema import Schema
from .PropertySchema import PropertySchema
from .ObjectSchema import ObjectSchema
from .ArraySchema import ArraySchema
from .MapSchema import MapSchema
from .FilterParamsSchema import FilterParamsSchema
from .PagingParamsSchema import PagingParamsSchema

==> pip_services3_commons-3.3.1.tar.gz: pip_services3_commons-3.3.1/pip_services3_commons/validate/__init__.py <==
# -*- coding: utf-8 -*-
"""
    pip_services3_commons.validate.__init__
    ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    
    Validation frameworks exist in various languages, but since this is one of the underlying
    functions that is incorporated into (various) obj packages, we decided to implement it
    in a portable format, for identical implementation across languages.
    
    :copyright: Conceptual Vision Consulting LLC 2018-2019, see AUTHORS for more details.
    :license: MIT, see LICENSE for more details.
"""

__all__ = [
    'ValidationResultType', 'ValidationResult', 'ValidationException',
    'IValidationRule', 'AndRule', 'OrRule', 'NotRule', 'ObjectComparator',
    'ValueComparisonRule', 'PropertiesComparisonRule',
    'OnlyOneExistRule', 'ExcludedRule', 'IncludedRule',
    'Schema', 'PropertySchema', 'ObjectSchema', 'ArraySchema', 'MapSchema',
    'FilterParamsSchema', 'PagingParamsSchema'
]

from .ValidationResultType import ValidationResultType
from .ValidationResult import ValidationResult
from .ValidationException import ValidationException
from .IValidationRule import IValidationRule
from .AndRule import AndRule
from .OrRule import OrRule
from .NotRule import NotRule
from .ObjectComparator import ObjectComparator
from .ValueComparisonRule import ValueComparisonRule
from .PropertiesComparisonRule import PropertiesComparisonRule
from .OnlyOneExistRule import OnlyOneExistRule
from .AtLeastOneExistRule import AtLeastOneExistRule
from .ExcludedRule import ExcludedRule
from .IncludedRule import IncludedRule
from .Schema import Schema
from .PropertySchema import PropertySchema
from .ObjectSchema import ObjectSchema
from .ArraySchema import ArraySchema
from .MapSchema import MapSchema
from .FilterParamsSchema import FilterParamsSchema
from .PagingParamsSchema import PagingParamsSchema
